hass-apps
=========

This is a collection of useful apps and snippets to empower Home Assistant
and AppDaemon even more.


Documentation
-------------

Read the `detailled documentation
<https://hass-apps.readthedocs.io/en/stable/>`_ hosted at readthedocs.


Donations
---------

.. note::

   I work on this project in my spare time, as many free software
   developers do. And of course, I enjoy this work a lot. There is no
   and will never be a need to pay anything for using this software.

However, if you want to honor the hundreds of hours continuously spent
with writing code and documentation, testing and providing support by
donating me a cup of coffee, a beer in the evening, my monthly hosting
fees or anything else embellishing my day a little more, that would be
awesome. If you decide doing so, I want to thank you very much! Please
be assured that I'm not presuming anybody to donate, it's entirely
your choice.

|paypal-recurring| Ensure ongoing development and support with a monthly
donation, no matter how small.

.. |paypal-recurring| image:: https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif
   :target: https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=PZPNNAJ93TVTQ&source=url

|paypal-once| Or make an one-time donation.

.. |paypal-once| image:: https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif
   :target: https://www.paypal.me/RSchindler

| ETH: 0xCE6B204B6AB5B93156f4FCD373482e148753beAb
| ZEC: t1RKFyt4qqtqdYfprf8HZoDHRNLNzhe35ED


Monthly Supporters
~~~~~~~~~~~~~~~~~~

These awesome supporters show their appreciation with a monthly donation
and help keeping hass-apps alive. If you want to be listed here, please
let me know!

* None yet.
